using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;

namespace SplitterAspectRatio {
	/// <summary>
	/// A simple demonstration of how to use a Layout event handler to make it so the
	/// two sides of a Splitter always have a fixed ratio of space assigned to each.
	///   - Ben Bederson, Feb 19, 2005
	/// </summary>
	public class SplitterAspectRatio : System.Windows.Forms.Form {
		private System.Windows.Forms.TreeView treeView;
		private System.Windows.Forms.Splitter splitter1;
		private System.Windows.Forms.ListView listView;
		private System.ComponentModel.Container components = null;

		float aspectRatio;  // Aspect ratio of right side of splitter over the left side.

		public SplitterAspectRatio() {
			InitializeComponent();

			Layout += new LayoutEventHandler(Form1_Layout);
			splitter1.SplitterMoving += new SplitterEventHandler(splitter1_SplitterMoving);
			aspectRatio = listView.Width / treeView.Width;
		}

		protected override void Dispose( bool disposing ) {
			if( disposing ) {
				if (components != null) {
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent() {
			this.treeView = new System.Windows.Forms.TreeView();
			this.splitter1 = new System.Windows.Forms.Splitter();
			this.listView = new System.Windows.Forms.ListView();
			this.SuspendLayout();
			// 
			// treeView
			// 
			this.treeView.BackColor = System.Drawing.SystemColors.Info;
			this.treeView.Dock = System.Windows.Forms.DockStyle.Left;
			this.treeView.ImageIndex = -1;
			this.treeView.Location = new System.Drawing.Point(0, 0);
			this.treeView.Name = "treeView";
			this.treeView.SelectedImageIndex = -1;
			this.treeView.Size = new System.Drawing.Size(121, 266);
			this.treeView.TabIndex = 0;
			// 
			// splitter1
			// 
			this.splitter1.Location = new System.Drawing.Point(121, 0);
			this.splitter1.Name = "splitter1";
			this.splitter1.Size = new System.Drawing.Size(3, 266);
			this.splitter1.TabIndex = 1;
			this.splitter1.TabStop = false;
			// 
			// listView
			// 
			this.listView.BackColor = System.Drawing.SystemColors.InactiveCaption;
			this.listView.Dock = System.Windows.Forms.DockStyle.Fill;
			this.listView.Location = new System.Drawing.Point(124, 0);
			this.listView.Name = "listView";
			this.listView.Size = new System.Drawing.Size(168, 266);
			this.listView.TabIndex = 2;
			// 
			// SplitterAspectRatio
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(292, 266);
			this.Controls.Add(this.listView);
			this.Controls.Add(this.splitter1);
			this.Controls.Add(this.treeView);
			this.Name = "SplitterAspectRatio";
			this.Text = "SplitterAspectRatio Tester";
			this.ResumeLayout(false);

		}
		#endregion

		[STAThread]
		static void Main() {
			Application.Run(new SplitterAspectRatio());
		}

		private void Form1_Layout(object sender, LayoutEventArgs e) {
			SuspendLayout();
			treeView.Width = (int)(ClientRectangle.Width / (1 + aspectRatio));
			ResumeLayout();
		}

		private void splitter1_SplitterMoving(object sender, SplitterEventArgs e) {
			aspectRatio = (float)(ClientRectangle.Width - e.X) / e.X;
		}
	}
}